#
# spec file for package python-wcwidth
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-wcwidth
Version:        0.2.13
Release:        1.3
Summary:        Number of Terminal column cells of wide-character codes
License:        MIT
URL:            https://github.com/jquast/wcwidth
Source:         https://github.com/jquast/wcwidth/archive/%{version}.tar.gz#/wcwidth-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %python_version_nodots < 38
Requires:       python-importlib-metadata
%endif
%python_subpackages

%description
This API is mainly for Terminal Emulator implementors -- any python
program that attempts to determine the printable width of a string on
a Terminal. It is implemented in python (no C library calls) and has
no 3rd-party dependencies.

It is certainly possible to use your Operating System's wcwidth(3)
and wcswidth(3) calls if it is POSIX-conforming, but this would not
be possible on non-POSIX platforms, such as Windows, or for
alternative Python implementations, such as jython.  It is also
commonly many releases older than the most current Unicode Standard
release files, which this project aims to track.

%prep
%autosetup -p1 -n wcwidth-%{version}
sed -i 's/--cov[-=a-z]*//g' tox.ini
# this option is nonsense
sed -i 's/looponfailroots.*//' tox.ini

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests

%files %{python_files}
%license LICENSE
%doc docs/intro.rst
%{python_sitelib}/*

%changelog
* Sat Jan  6 2024 Dirk Müller <dmueller@suse.com>
- update to 0.2.13:
  * Bugfix zero-width support for Hangul Jamo (Korean) #111
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.2.12:
  * Include tests files in the source distribution (PR #98, PR
  * **Bugfix** accounting of some kinds of emoji sequences using
    U+FE0F
  * Variation Selector 16 (PR #97).
  * **Bugfix** zero-width characters used in Emoji ZWJ sequences,
    Balinese, Jamo, Devanagari, Tamil, Kannada and others (PR #91).
  * Include requirements files in the source distibution (PR
    [#83]).
  * Update Unicode version to 15.1.0
  * Add testing support for Python 3.12
  * Update README
  * Update requirements
  * Enable GitHub Actions CI
  * Prepare release 0.2.7
  * Update tox envs in README
  * Include bin, docs, and tox.ini in the source distribution
* Mon Aug  7 2023 Dirk Müller <dmueller@suse.com>
- use actual package name for importlib-metadata requires
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Tue Jan 17 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.2.6:
  * Fix example for str.rjust(20, '_')
  * Add CodeQL workflow for GitHub code scanning
  * Switch to using importlib.metadata
  * Use a new jinja2 templating process to update library to latest unicode
- Drop patch remove-pkg_resources.patch.
- Remove Python 2 gubbins.
* Wed Nov 23 2022 Johannes Kastl <kastl@b1-systems.de>
- add explicit Requires for python-importlib_metadata for Python < 3.8
* Mon Jul 18 2022 Steve Kowalik <steven.kowalik@suse.com>
- Add patch remove-pkg_resources.patch:
  * Use importlib.metadata rather than pkg_resources.
- Since importlib.metadata is not as a stickler as pkg_resources is, remove
  multibuild.
* Wed Jun  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix the %%doc files. README.rst is a symlink pointing to
  docs/intro.rst.
* Mon Oct 12 2020 Marketa Calabkova <mcalabkova@suse.com>
- Remove nonsense keyword (breaks pytest)
* Fri Jul 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.2.5
  * Do not depend on pkg_resources module for list_versions() function.
* Sun Jun 14 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.2.4
  * minor "bugfix" to avoid using pkg_resources module on import, 7918f58
  * may help xonsh xonsh/xonsh#3607
* Mon Jun  8 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.2.3
  * add tests
* Mon Jun  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add missing python2 dependency for Leap to work
* Tue Jun  2 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 0.2.2
  * Enhancement: Unicode version may be selected by exporting the
    Environment variable UNICODE_VERSION, such as 13.0, or 6.3.0.
    See the jquast/ucs-detect CLI utility for automatic detection.
  * Enhancement: API Documentation is published to readthedocs.org.
  * Updated tables for all Unicode Specifications with files published
    in a programmatically consumable format.
* Wed May  6 2020 Steve Kowalik <steven.kowalik@suse.com>
- Convert to multibuild to break a self-requires loop.
* Wed Mar 25 2020 pgajdos@suse.com
- version update to 0.1.9
  * Performance optimization by @avylove , PR #35.
  * Updated tables to Unicode Specification 13.0.0.
* Thu Feb  6 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.1.8
  * Unicode v12 and proj. maintenence
  * remove static analysis
  * EastAsianWidth v9 -> v12
  * README and tox.ini
* Wed Oct  2 2019 John Vandenberg <jayvdb@gmail.com>
- Re-active test suite
- Remove test suite from runtime package
- Run fdupes
* Thu Mar  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix test macro expansion
* Thu Sep  6 2018 Tomáš Chvátal <tchvatal@suse.com>
- Drop devel dependency
- Install license file
* Mon Apr  3 2017 toddrme2178@gmail.com
- Fix source URL.
* Sat Apr  1 2017 toddrme2178@gmail.com
- Update to version 0.1.7
  * **Updated** tables to Unicode Specification 9.0.0. (`PR #18`_).
- Update to version 0.1.6
  0.1.6 *2016-01-08 Production/Stable*
  * ``LICENSE`` file now included with distribution.
- Update to version 0.1.5
  * **Bugfix**:
    Resolution of "combining_ character width" issue, most especially
    those that previously returned -1 now often (correctly) return 0.
    resolved by `Philip Craig`_ via `PR #11`_.
  * **Deprecated**:
    The module path ``wcwidth.table_comb`` is no longer available,
    it has been superseded by module path ``wcwidth.table_zero``.
- Implement single-spec version
* Mon Jan 30 2017 rjschwei@suse.com
- Include in SLE 12 (bsc#1002895, FATE#321630)
* Wed May  6 2015 toddrme2178@gmail.com
- Initial version
  + Version 0.1.4
